/*************************************************************************
**  
**  This program solves the optimal growth model via GENSYS
**  Author: David N. DeJong
**
**************************************************************************/

/* filename: optgrowth.prg
**
*/

/*
Goal: convert system of nonlinear model equations into a linear system
of the form

(1)	x(t) = T1x(t-1) + T0z(t) = T1x(t-1) + e(t), 

where Eee' = Q,
x(t) is an nx1 vector of model variables,
and z is a jx1 vector of exogenous disturbances.

Variables (logged deviations from ss xbar) are contained in the nx1 vector x.  
Ordering:
x = [y c i k a ]';

*/

new;
dlibrary -a PszTgSen,PsdTgSen;
#include gensys.src

/* establish global variables */
tme = 0;            // indicator variable used to construct A and B
nvars = 5;          // # of variables included in the model
neulers = 1;        // # of euler equations included in the model
nshocks = 1;        // # of structural shocks
xbar = 0;           // will contain ss values

// establish parameters: alpha, beta, delta, phi, rho, sige
let p[6,1] = 0.33 0.96 0.1 2 0.9 0.001;

/* load procedures needed to solve model */
#include optgrowth.src

xbar = steady(p);

{TC,T1,T0,RC}=modelsol(p);      // x(t) = TC + T1x(t-1) + T0z(t)
                                // rc[1] = 1: sln exists; rc[2] = 1: sln is unique

q = (t0*p[6])*(t0*p[6])';       // vcv matrix of e(t) = T0z(t)

"lag matrix of system:" t1;?;
"std of e's:" sqrt(diag(q));
